=========================
Notebooks for our article
=========================

These notebooks present all the instructions that we used to generate the numerical data, tables and figures of
our article, currently under submission: *Voter Coordination in Elections: A Case for Approval Voting* (François Durand,
Antonin Macé and Matías Núñez). The references inside parentheses correspond to the section numbers in the article.

.. toctree::

   Ordinal Equilibria Condorcet Consistency of Approval Voting (5.1)
   Dynamic Process 01 Base Case (6.2.1, 6.2.4, 6.3, C.2, C.3, C.7)
   Dynamic Process 02 Condorcet Profiles (6.2.1, 6.2.2, C.5)
   Dynamic Process 03 Non-Condorcet Profiles (6.2.1, C.5)
   Dynamic Process 04 Single-Peaked Profiles (6.2.2)
   Dynamic Process 05 With Some Expressive Voters (C.6)
   Dynamic Process 06 With Expressive Voters and a CW (6.4)
   Dynamic Process 07.a Robustness to the Belief Updating Parameter (C.1)
   Dynamic Process 07.b Robustness to the Belief Updating Parameter (with CW) (C.1)
   Dynamic Process 08.a Robustness to the Share of Updating Voters (C.1)
   Dynamic Process 08.b Robustness to the Share of Updating Voters (with CW) (C.1)
   Dynamic Process 09 Robustness to the Distribution of Preference Intensities (C.2)
   Dynamic Process 10 Robustness to the Initial Poll (C.3)
   Divided Preferences AV (6.2.3)
   Divided Preferences PL (6.2.3)
   Divided Preferences APL (C.4)
   A (difficult) example (B.4)
   The Bad Apple Example (C.4.2)
   Confidence Intervals
